<!DOCTYPE style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN">

<style-specification id="docbook-l10n-usen">

;; $Id: dbl1usen.dsl 0.1 1997/07/31 14:51:33 nwalsh Exp $

;; ----------------------------- Localization -----------------------------

;; If you create a new version of this file, please send it to
;; Norman Walsh, norm@berkshire.net
;;
;; See also (xref-unlabeled-section) in dblink.dsl if you have
;; cross references to unlabeled sections.

;; Should the TOC come first or last?
;;
(define %generate-toc-in-front% #t)

;; gentext-element-name returns the generated text that should be 
;; used to make reference to the selected element.
;;
(define (gentext-element-name giname)
  (case giname
    (("APPENDIX") "Appendix")
    (("CAUTION") "CAUTION")
    (("CHAPTER") "Chapter")
    (("COPYRIGHT") "Copyright")
    (("EXAMPLE") "Example")
    (("FIGURE") "Figure")
    (("IMPORTANT") "IMPORTANT")
    (("NOTE") "NOTE")
    (("PART") "Part")
    (("PREFACE") "Preface")
    (("REFNAME") "Name")
    (("REVHISTORY") "Revision History")
    (("REVISION") "Revision")
    (("SECT1") "Section")
    (("SECT2") "Section")
    (("SECT3") "Section")
    (("SECT4") "Section")
    (("SECT5") "Section")
    (("STEP") "Step")
    (("TABLE") "Table")
    (("TIP") "TIP")
    (("TOC") "Table of Contents")
    (("WARNING") "WARNING")
    (else (string-append "UNEXPECTED-ELEMENT-NAME: " giname))))

;; gentext-element-name-space returns gentext-element-name with a 
;; trailing space, if gentext-element-name isn't "".
;;
(define (gentext-element-name-space giname)
  (string-with-space (gentext-element-name giname)))

;; gentext-intra-label-sep returns the seperator to be inserted
;; between multiple occurances of a label (or parts of a label)
;; for the specified element.  Most of these are for enumerated
;; labels like "Figure 2-4", but this function is used elsewhere
;; (e.g. REFNAME) with a little abuse.
;;
(define (gentext-intra-label-sep giname)
  (case giname
    (("EXAMPLE") "-")
    (("FIGURE") "-")
    (("REFNAME") ", ")
    (("REFSECT1") ".")
    (("REFSECT2") ".")
    (("REFSECT3") ".")
    (("SECT1") ".")
    (("SECT2") ".")
    (("SECT3") ".")
    (("SECT4") ".")
    (("SECT5") ".")
    (("STEP") ".")
    (("TABLE") "-")
    (("_pagenumber") "-")  ;; page number psuedo element
    (else "")))

;; gentext-intra-label-sep returns the seperator to be inserted
;; between a label and the text following the label for the
;; specified element.  Most of these are for use between
;; enumerated labels and titles like "1. Chapter One Title", but
;; this function is used elsewhere (e.g. NOTE) with a little
;; abuse.
;;
(define (gentext-label-title-sep giname)
  (case giname
    (("APPENDIX") ". ")
    (("CAUTION") "")
    (("CHAPTER") ". ")
    (("EXAMPLE") ". ")
    (("FIGURE") ". ")
    (("IMPORTANT") ": ")
    (("NOTE") ": ")
    (("ORDEREDLIST") ". ")
    (("PART") ". ")
    (("PREFIX") ". ")
    (("REFSECT1") ". ")
    (("REFSECT2") ". ")
    (("REFSECT3") ". ")
    (("SECT1") ". ")
    (("SECT2") ". ")
    (("SECT3") ". ")
    (("SECT4") ". ")
    (("SECT5") ". ")
    (("STEP") ". ")
    (("TABLE") ". ")
    (("TIP") ": ")
    (("WARNING") "")
    (else "")))

;; gentext-xref-element-name returns the generated text that should be 
;; used to make reference to the selected element in a cross reference.
;;
(define (gentext-xref-element-name giname)
  (case giname
    (("APPENDIX") "Appendix")
    (("CAUTION") "CAUTION")
    (("CHAPTER") "Chapter")
    (("COPYRIGHT") "Copyright")
    (("EXAMPLE") "Example")
    (("FIGURE") "Figure")
    (("IMPORTANT") "IMPORTANT")
    (("NOTE") "NOTE")
    (("PART") "Part")
    (("PREFACE") "Preface")
    (("REFNAME") "Name")
    (("REVHISTORY") "Revision History")
    (("REVISION") "Revision")
    (("SECT1") "Section")
    (("SECT2") "Section")
    (("SECT3") "Section")
    (("SECT4") "Section")
    (("SECT5") "Section")
    (("STEP") "step")
    (("TABLE") "Table")
    (("TIP") "TIP")
    (("TOC") "Table of Contents")
    (("WARNING") "WARNING")
    (else (string-append "UNEXPECTED-ELEMENT-NAME: " giname))))

(define (gentext-xref-element-name-space giname)
  (string-with-space (gentext-xref-element-name giname)))

(define (gentext-xref-label-title-sep giname)
  (case giname
    (("APPENDIX") ", ")
    (("CHAPTER") ", ")
    (("EXAMPLE") ", ")
    (("FIGURE") ", ")
    (("PART") ", ")
    (("PREFIX") ", ")
    (("REFSECT1") ", ")
    (("REFSECT2") ", ")
    (("REFSECT3") ", ")
    (("SECT1") ", ")
    (("SECT2") ", ")
    (("SECT3") ", ")
    (("SECT4") ", ")
    (("SECT5") ", ")
    (("TABLE") ", ")
    (else "")))

(define %gentext-by% "by") ;; e.g. Copyright 1997 "by" A. Nonymous
                           ;; Authored "by" Jane Doe

(define %gentext-page% "Page")

(define %gentext-start-quote%
  (make entity-ref name: "ldquo"))

(define %gentext-end-quote%
  (make entity-ref name: "rdquo"))

(define %gentext-table-footnote-caption% "Notes:")

</style-specification>
